pub fn is_straight_planar(curve: &PlanarCurve) -> boolExpand description
Whether a planar curve is a straight line in parameter space.
pub fn is_straight_planar(curve: &PlanarCurve) -> boolWhether a planar curve is a straight line in parameter space.