simplify

Function simplify 

pub fn simplify(
    mesh: &Triangulation,
    target: Target,
    tol: Tolerances,
) -> OgeomResult<Simplified>
Decimate a mesh.

Errors

OgeomError::Construction if the target is not a positive count or a positive distance, or the mesh names a vertex it does not have.